@@ -311,3 +311,50 @@ class GitIgnoreSpecTest(unittest.TestCase):
 			'anydir/file.txt',
 			'product_dir/file.txt',
 		})
+
+	def test_05_issue_39(self):
+		"""
+		Test excluding files in a directory.
+		"""
+		spec = GitIgnoreSpec.from_lines([
+			'*.log',
+			'!important/*.log',
+			'trace.*',
+		])
+		files = {
+			'a.log',
+			'b.txt',
+			'important/d.log',
+			'important/e.txt',
+			'trace.c',
+		}
+		ignores = set(spec.match_files(files))
+		self.assertEqual(ignores, {
+			'a.log',
+			'trace.c',
+		})
+		self.assertEqual(files - ignores, {
+			'b.txt',
+			'important/d.log',
+			'important/e.txt',
+		})
+
+	def test_06_issue_64(self):
+		"""
+		Test using a double asterisk pattern.
+		"""
+		spec = GitIgnoreSpec.from_lines([
+			"**",
+		])
+		files = {
+			'x',
+			'y.py',
+			'A/x',
+			'A/y.py',
+			'A/B/x',
+			'A/B/y.py',
+			'A/B/C/x',
+			'A/B/C/y.py',
+		}
+		ignores = set(spec.match_files(files))
+		self.assertEqual(ignores, files)
